==> inti-media-1.0.1-386369.tar: src/Plugin/MediaHandler.php <==
<?php
declare(strict_types=1);

namespace Inti\Media\Plugin;

use Inti\Media\Exception\InvalidArgumentException;
use Inti\Media\Model\ImagePath;
use Inti\Media\Service\ImageManager;
use Inti\Wp\Plugin\PluginInterface;
use Symfony\Contracts\Cache\CacheInterface;
use function add_filter;
use function file_get_contents;
use function is_numeric;
use function preg_match;
use function wp_get_additional_image_sizes;

/**
 * Class MediaUrls
 *
 * @package Inti\Media\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-media
 */
final class MediaHandler implements PluginInterface
{
    private ImageManager $images;
    private CacheInterface $cache;

    /** @var string[] */
    private array $wpSizes = [
        'large',
        'medium',
        'thumb',
        'thumbnail',
    ];

    public function __construct(ImageManager $images, CacheInterface $cache)
    {
        $this->images = $images;
        $this->cache = $cache;
    }

    public function run(?array $options = null): void
    {
        add_filter('wp_get_attachment_image_src', [$this, 'get_attachment_image_src'], 10, 3);
    }

    /**
     * @param array|false $image
     * @param string|int $attachment_id
     * @param string|int[] $size
     * @return array|false
     * @throws \Psr\Cache\InvalidArgumentException
     */
    public function get_attachment_image_src($image, $attachment_id, $size)
    {
        if ($image === false && is_string($attachment_id) && !is_numeric($attachment_id)) {
            if (preg_match('/(.*)\.([a-z0-9]{32})(\.[^.]+)$/', $attachment_id, $matches)) {
                $attachment_id = $matches[1] . $matches[3];
            }

            if (preg_match('#^https?://(.+)$#', $attachment_id, $matches)) {
                $path = new ImagePath($matches[1]);
                $path = $path->sanitize()->setExtension('webp')->getRawPath();

                if (!$this->images->has($path)) {
                    $imageData = file_get_contents($attachment_id);
                    $this->images->write($path, $imageData);
                }
            } else if ($this->images->has($attachment_id)) {
                $path = $attachment_id;
            }

            if (isset($path)) {
                $path = new ImagePath($path);
                $this->setSize($path, $size);

                $url = '/media/' . $path->getFullPath();
                [$width, $height] = $this->getImageSize($path->getFullPath());

                return [$url, $width, $height, $path->isResized()];
            }
        }

        return $image;
    }

    /**
     * @param string $path
     * @return array
     * @throws \Psr\Cache\InvalidArgumentException
     */
    private function getImageSize(string $path): array
    {
        $key = md5($path);

        $meta = $this->cache->get($key, function () use ($path) {
            $image = imagecreatefromstring($this->images->read($path));

            return [
                'width' => imagesx($image),
                'height' => imagesy($image),
            ];
        });

        return [$meta['width'], $meta['height']];
    }

    /**
     * @param ImagePath $path
     * @param string|int[] $size
     */
    private function setSize(ImagePath $path, $size): void
    {
        if (!is_string($size) && !is_array($size)) {
            throw InvalidArgumentException::typeForArgument('$requestedSize', 'string or array', $size);
        }

        if (is_array($size)) {
            $path->setWidth($size[0] ?? null)
                ->setHeight($size[1] ?? null)
                ->setCropped($size[2] ?? false);
            return;
        }

        if ('full' === $size) {
            return;
        }

        if (in_array($size, $this->wpSizes)) {
            if ($size === 'thumb') {
                $size = 'thumbnail';
            }

            $path->setWidth(intval(get_option("{$size}_size_w", null)))
                ->setHeight(intval(get_option("{$size}_size_h", null)))
                ->setCropped(boolval(get_option("{$size}_crop", false)));
            return;
        }

        $_wp_additional_image_sizes = wp_get_additional_image_sizes();

        if (!array_key_exists($size, $_wp_additional_image_sizes)) {
            throw InvalidArgumentException::scalarValueForArgument(
                '$size',
                array_keys($_wp_additional_image_sizes),
                $size
            );
        }

        $path->setWidth($_wp_additional_image_sizes[$size]['width'] ?? null)
            ->setHeight($_wp_additional_image_sizes[$size]['height'] ?? null)
            ->setCropped(boolval($_wp_additional_image_sizes[$size]['crop'] ?? false));
    }
}

==> inti-media-1.0.4-820522.tar: src/Plugin/MediaHandler.php <==
<?php
declare(strict_types=1);

namespace Inti\Media\Plugin;

use Inti\Media\Exception\InvalidArgumentException;
use Inti\Media\Model\ImagePath;
use Inti\Media\Service\ImageManager;
use Inti\Wp\Plugin\PluginInterface;
use Laminas\Filter\FilterInterface;
use Symfony\Contracts\Cache\CacheInterface;
use function add_filter;
use function file_get_contents;
use function is_numeric;
use function preg_match;
use function wp_get_additional_image_sizes;

/**
 * Class MediaUrls
 *
 * @package Inti\Media\Plugin
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/oktan-nautika/inti-media
 */
final class MediaHandler implements PluginInterface
{
    private CacheInterface  $cache;
    private ImageManager    $images;
    private FilterInterface $pathFilter;

    /** @var string[] */
    private array $wpSizes = [
        'large',
        'medium',
        'thumb',
        'thumbnail',
    ];

    public function __construct(ImageManager $images, CacheInterface $cache, FilterInterface $pathFilter)
    {
        $this->images = $images;
        $this->cache = $cache;
        $this->pathFilter = $pathFilter;
    }

    public function run(?array $options = null): void
    {
        add_filter('wp_get_attachment_image_src', [$this, 'get_attachment_image_src'], 10, 3);
    }

    /**
     * @param array|false $image
     * @param string|int $attachment_id
     * @param string|int[] $size
     * @return array|false
     * @throws \Psr\Cache\InvalidArgumentException
     */
    public function get_attachment_image_src($image, $attachment_id, $size)
    {
        if ($image === false && is_string($attachment_id) && !is_numeric($attachment_id)) {
            if (preg_match('/(.*)\.([a-z0-9]{32})(\.[^.]+)$/', $attachment_id, $matches)) {
                $attachment_id = $matches[1] . $matches[3];
            }

            if (preg_match('#^https?://(.+)$#', $attachment_id, $matches)) {
                $path = $this->pathFilter->filter($matches[1]);
                $path = new ImagePath($path);
                $path = $path->setExtension('webp')->getRawPath();

                if (!$this->images->has($path)) {
                    $imageData = file_get_contents($attachment_id);
                    $this->images->write($path, $imageData);
                }
            } else if ($this->images->has($attachment_id)) {
                $path = $attachment_id;
            }

            if (isset($path)) {
                $path = new ImagePath($path);
                $this->setSize($path, $size);

                $url = '/media/' . $path->getFullPath();
                [$width, $height] = $this->getImageSize($path->getFullPath());

                return [$url, $width, $height, $path->isResized()];
            }
        }

        return $image;
    }

    /**
     * @param string $path
     * @return array
     * @throws \Psr\Cache\InvalidArgumentException
     */
    private function getImageSize(string $path): array
    {
        $key = md5($path);

        $meta = $this->cache->get($key, function () use ($path) {
            $image = imagecreatefromstring($this->images->read($path));

            return [
                'width' => imagesx($image),
                'height' => imagesy($image),
            ];
        });

        return [$meta['width'], $meta['height']];
    }

    /**
     * @param ImagePath $path
     * @param string|int[] $size
     */
    private function setSize(ImagePath $path, $size): void
    {
        if (!is_string($size) && !is_array($size)) {
            throw InvalidArgumentException::typeForArgument('$requestedSize', 'string or array', $size);
        }

        if (is_array($size)) {
            $path->setWidth($size[0] ?? null)
                ->setHeight($size[1] ?? null)
                ->setCropped($size[2] ?? false);
            return;
        }

        if ('full' === $size) {
            return;
        }

        if (in_array($size, $this->wpSizes)) {
            if ($size === 'thumb') {
                $size = 'thumbnail';
            }

            $path->setWidth(intval(get_option("{$size}_size_w", null)))
                ->setHeight(intval(get_option("{$size}_size_h", null)))
                ->setCropped(boolval(get_option("{$size}_crop", false)));
            return;
        }

        $_wp_additional_image_sizes = wp_get_additional_image_sizes();

        if (array_key_exists($size, $_wp_additional_image_sizes)) {
            $path->setWidth($_wp_additional_image_sizes[$size]['width'] ?? null)
                ->setHeight($_wp_additional_image_sizes[$size]['height'] ?? null)
                ->setCropped(boolval($_wp_additional_image_sizes[$size]['crop'] ?? false));
        }
    }
}
